@@ -3,9 +3,11 @@
 import os
 import re
 try:
-    import configparser # py3
+    # py3
+    import configparser
 except ImportError:
-    import ConfigParser as configparser # py2
+    # py2
+    import ConfigParser as configparser # type: ignore
 
 class ReadConfigError(Exception):
     """ errors for read_configs"""
@@ -27,6 +29,7 @@ def read_configs(profile=None):
 
     config['global_request_timeout'] = os.getenv('CLOUDFLARE_GLOBAL_REQUEST_TIMEOUT')
     config['max_request_retries'] = os.getenv('CLOUDFLARE_MAX_REQUEST_RETRIES')
+    config['http_headers'] = os.getenv('CLOUDFLARE_HTTP_HEADERS')
 
     # grab values from config files
     cp = configparser.ConfigParser()
@@ -36,7 +39,7 @@ def read_configs(profile=None):
             os.path.expanduser('~/.cloudflare.cfg'),
             os.path.expanduser('~/.cloudflare/cloudflare.cfg')
         ])
-    except:
+    except OSError:
         raise ReadConfigError("%s: configuration file error" % ('.cloudflare.cfg')) from None
 
     if len(cp.sections()) == 0 and profile is not None and len(profile) > 0:
@@ -50,7 +53,7 @@ def read_configs(profile=None):
         if cp.has_section('Cloudflare'):
             profile = 'Cloudflare'
 
-    ## still not found - then set to to CloudFlare for legacy reasons
+    # still not found - then set to to CloudFlare for legacy reasons
     if profile is None:
         profile = "CloudFlare"
 
@@ -62,11 +65,15 @@ def read_configs(profile=None):
         if not cp.has_section(profile):
             raise ReadConfigError("%s: configuration section missing - configuration file only has these sections: %s" % (profile, ','.join(cp.sections()))) from None
 
-        for option in ['email', 'key', 'token', 'certtoken', 'extras', 'base_url', 'openapi_url', 'global_request_timeout', 'max_request_retries']:
+        for option in ['email', 'key', 'token', 'certtoken', 'extras', 'base_url', 'openapi_url', 'global_request_timeout', 'max_request_retries', 'http_headers']:
             try:
                 config_value = cp.get(profile, option)
                 if option == 'extras':
+                    # we join all values together as one space seperated strings
                     config[option] = re.sub(r"\s+", ' ', config_value)
+                elif option == 'http_headers':
+                    # we keep lines as is for now
+                    config[option] = config_value
                 else:
                     config[option] = re.sub(r"\s+", '', config_value)
                 if config[option] is None or config[option] == '':
@@ -85,9 +92,11 @@ def read_configs(profile=None):
                 except (configparser.NoOptionError, configparser.NoSectionError):
                     pass
 
-    # do any final cleanup - only needed for extras (which are multiline)
+    # do any final cleanup - only needed for extras and http_headers (which are multiline)
     if 'extras' in config and config['extras'] is not None:
         config['extras'] = config['extras'].strip().split(' ')
+    if 'http_headers' in config and config['http_headers'] is not None:
+        config['http_headers'] = [h for h in config['http_headers'].split('\n') if len(h) > 0]
 
     # remove blank entries
     for x in sorted(config.keys()):
